@@ -52,7 +52,7 @@ static          Pixmap
 create_icon ()
 {
   char            radius = 24;
-  char            color = 4 * 32;
+  unsigned char            color = 4 * 32;
   XImage         *img;
   char           *data;
   Pixmap          pixmap;
@@ -165,7 +165,6 @@ GetImage (VScreenType * pixmap)	/*Work as in shared memory mose but use
   gettimeofday (&VnewClk, NULL);
   VendSleep = VlastClk.tv_usec;
   VfTime = 1000000 / 25 * 12;
-  printf ("a\n");
   pixmap->ximage = XCreateImage (dp, DefaultVisual (dp, screen),
 				 depth, ZPixmap, 0,
 				 NULL, Width, Height, bpp * 8, 0);
@@ -175,14 +174,12 @@ GetImage (VScreenType * pixmap)	/*Work as in shared memory mose but use
       return 0;
     }
   /*Calculate size of shared memory */
-  printf ("a\n");
   memsize = ((Width + 1) * (Height + 1) * bpp);
   if ((data = malloc (memsize)) == NULL)
     {
       printf ("Can't malloc memory for image\n");
       return 0;
     }
-  printf ("a\n");
   pixmap->ximage->data = (char *) data;
   printf ("Performing connection benchmark....");
   fflush (stdout);
@@ -315,7 +312,7 @@ initialize (char **argv, int argc)
   XSizeHints     *sizehints;
   XTextProperty   windowName;
   XTextProperty   iconName;
-  char           *title = "Koules for X version 1.2 by Jan Hubicka";
+  char           *title = "Koules for X version 1.4 by Jan Hubicka";
   char           *title1 = "Koules";
 
   Font            f;
@@ -638,7 +635,7 @@ main (int argc, char **argv)
 	  "                                The  game\n"
 	  "                               K O U L E S\n"
 	  "                                  For X\n"
-	  "				  Version 1.2\n"
+	  "				  Version 1.4\n"
 	  "\n\n\n\n"
 	  "                     Copyright(c) Jan Hubicka 1995, 1996\n\n\n");
   useprivate = 0;
